@@ -1,9 +1,9 @@
 #' @name zen4R
 #' @aliases zen4R-package
 #' @aliases zen4R
-#' @docType package
-#' 
+#'
 #' @importFrom R6 R6Class
+#' @import cli
 #' @import methods
 #' @import httr
 #' @import jsonlite
@@ -14,6 +14,7 @@
 #' @importFrom tools md5sum
 #' @import atom4R
 #' @importFrom utf8 utf8_encode
+#' @importFrom plyr rbind.fill
 #' 
 #' @title Interface to 'Zenodo' REST API
 #' @description Provides an Interface to 'Zenodo' (<https://zenodo.org>) REST API, 
@@ -22,4 +23,4 @@
 #'  
 #'@author Emmanuel Blondel \email{emmanuel.blondel1@@gmail.com}
 #'
-NULL
\ No newline at end of file
+"_PACKAGE"
\ No newline at end of file
