@@ -15,14 +15,15 @@
 #' DCAT, JSON, JSON-LD, GeoJSON, MARCXML.
 #' @param append_format wether format name has to be appended to the filename. Default is \code{TRUE} (for
 #' backward compatibility reasons). Set it to \code{FALSE} if you want to use only the \code{filename}.
+#' @param sandbox Use the sandbox infrastructure. Default is \code{FALSE}
 #' @param logger a logger to print Zenodo API-related messages. The logger can be either NULL, 
 #' "INFO" (with minimum logs), or "DEBUG" (for complete curl http calls logs)
 #' @return the exported file name (with extension)
 #' @export
 #' 
-export_zenodo = function(doi, filename, format, append_format = TRUE, logger = NULL){
+export_zenodo = function(doi, filename, format, append_format = TRUE, sandbox = FALSE, logger = NULL){
   #get
-  rec = get_zenodo(doi = doi, logger = logger)
+  rec = get_zenodo(doi = doi, sandbox = sandbox, logger = logger)
   #download
   rec$exportAs(filename = filename, format = format, append_format = append_format)
 }
\ No newline at end of file
